import pycurl
import urllib
import xmltodict
try:
    from io import BytesIO
except ImportError:
    from StringIO import StringIO as BytesIO

class ARDICore:
    def __init__(self, srv, prt):
        self.server = srv
        self.port = prt
        self.consolidatorhost = srv
        self.consolidatorport = 5336

    def Connect(self):
        buffer = BytesIO()
        ar = pycurl.Curl()
        ar.setopt(ar.URL, 'http://' + self.server + ':' + str(self.port) + '/api/connect.php')
        ar.setopt(ar.WRITEFUNCTION, buffer.write)
        ar.perform()        

        # HTTP response code, e.g. 200.
        if ar.getinfo(ar.RESPONSE_CODE) == 200:
            ar.close()
            
            xml = xmltodict.parse(buffer.getvalue())

            for d in xml['ardi']['service']:
                if d['@name'] == 'data':
                    try:
                        self.consolidatorport = d['@port']
                    except:
                        pass
                    
                    try:
                        self.consolidatorhost = d['@host']
                    except:
                        pass                
            
            return True
        else:
            ar.close()
            return False        
        

    def GetConfiguration(self):
        buffer = BytesIO()
        ar = pycurl.Curl()
        ar.setopt(ar.URL, 'http://' + self.server + ':' + str(self.port) + '/api/getconfiguration.php')
        ar.setopt(ar.WRITEFUNCTION, buffer.write)
        ar.perform()        

        # HTTP response code, e.g. 200.
        if ar.getinfo(ar.RESPONSE_CODE) == 200:
            #print buffer.getvalue()
            xml = xmltodict.parse(buffer.getvalue())

            rels = []
            props = []

            for ele in xml['config']['relations']['relationship']:
                rels.append({ 'name': ele['@name'], 'id': ele['@id'] })                
            
            for ele in xml['config']['properties']['property']:
                props.append({ 'name' : ele['@name'], 'type' : ele['@type'], 'id' : ele['@id'] })
        else:
            return None
                
        ar.close()        
        return [rels,props]

    def GetDataSourceInfo(self):
        buffer = BytesIO()
        ar = pycurl.Curl()
        ar.setopt(ar.URL, 'http://' + self.server + ':' + str(self.port) + '/api/getdatasources.php')
        ar.setopt(ar.WRITEFUNCTION, buffer.write)
        ar.perform()        

        # HTTP response code, e.g. 200.
        if ar.getinfo(ar.RESPONSE_CODE) == 200:            
            xml = xmltodict.parse(buffer.getvalue())

            drivers = []
            dsources = []

            for ele in xml['config']['drivers']['driver']:
                drivers.append({ 'name': ele['@name'], 'port': ele['@port'], 'code' : ele['@code'] })
            
            for ele in xml['config']['datasources']['source']:
                dsources.append({ 'name' : ele['@name'], 'type' : ele['@type'], 'id' : ele['@id'], 'port' : ele['@port'] })
        else:
            return None
                
        ar.close()        
        return [drivers,dsources]